@@ -6,6 +6,7 @@ from enum import Enum
 
 class QueryPresence(Enum):
     """Defines possible behaviours for the term's presence in a document."""
+
     OPTIONAL = 1  # default
     REQUIRED = 2
     PROHIBITED = 3  # documents that contain this term will not be returned
@@ -25,7 +26,7 @@ class Query(object):
     # without having to manually do any string concatenation.
     # The wildcard constants can be bitwise combined to select both leading and
     # trailing wildcards.
-    WILDCARD = '*'
+    WILDCARD = "*"
     WILDCARD_NONE = 0
     WILDCARD_LEADING = 1
     WILDCARD_TRAILING = 2
@@ -36,7 +37,8 @@ class Query(object):
 
     def __repr__(self):
         return '<Query fields="{}" clauses="{}">'.format(
-            ','.join(self.all_fields), ','.join(c.term for c in self.clauses))
+            ",".join(self.all_fields), ",".join(c.term for c in self.clauses)
+        )
 
     def clause(self, *args, **kwargs):
         """Adds a `lunr.Clause` to this query.
@@ -58,12 +60,14 @@ class Query(object):
         if not clause.fields:
             clause.fields = self.all_fields
 
-        if ((clause.wildcard & Query.WILDCARD_LEADING) and
-                (clause.term[0] != Query.WILDCARD)):
+        if (clause.wildcard & Query.WILDCARD_LEADING) and (
+            clause.term[0] != Query.WILDCARD
+        ):
             clause.term = Query.WILDCARD + clause.term
 
-        if ((clause.wildcard & Query.WILDCARD_TRAILING) and
-                (clause.term[-1] != Query.WILDCARD)):
+        if (clause.wildcard & Query.WILDCARD_TRAILING) and (
+            clause.term[-1] != Query.WILDCARD
+        ):
             clause.term = clause.term + Query.WILDCARD
 
         self.clauses.append(clause)
@@ -97,8 +101,8 @@ class Query(object):
         the expected results.
         """
         return all(
-            clause.presence == QueryPresence.PROHIBITED
-            for clause in self.clauses)
+            clause.presence == QueryPresence.PROHIBITED for clause in self.clauses
+        )
 
 
 class Clause(object):
@@ -120,10 +124,17 @@ class Clause(object):
         presence (QueryPresence, optional): Behaviour for a terms presence
             in a document.
     """
+
     def __init__(
-            self, term=None, fields=None, edit_distance=0,
-            use_pipeline=True, boost=1, wildcard=Query.WILDCARD_NONE,
-            presence=QueryPresence.OPTIONAL):
+        self,
+        term=None,
+        fields=None,
+        edit_distance=0,
+        use_pipeline=True,
+        boost=1,
+        wildcard=Query.WILDCARD_NONE,
+        presence=QueryPresence.OPTIONAL,
+    ):
         super(Clause, self).__init__()
         self.term = term
         self.fields = fields or []
